@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_WORKBOOK_PRIV_H_
 # define _GNM_WORKBOOK_PRIV_H_
 
-#include "workbook.h"
+#include <workbook.h>
 #include <goffice/goffice.h>
 
 G_BEGIN_DECLS
@@ -10,6 +9,7 @@ G_BEGIN_DECLS
 struct _Workbook {
 	GODoc	doc;
 
+#ifndef __GI_SCANNER__
 	GPtrArray *wb_views;
 
 	GPtrArray  *sheets;
@@ -17,10 +17,16 @@ struct _Workbook {
 	GHashTable *sheet_order_dependents;
 	GHashTable *sheet_local_functions;
 
+	gboolean sheet_size_cached;
+	GnmSheetSize sheet_size;
+
 	gboolean is_placeholder;
 
 	GOFileFormatLevel  file_format_level;
+	GOFileFormatLevel  file_export_format_level;
 	GOFileSaver	*file_saver;
+	GOFileSaver	*file_exporter;
+	char            *last_export_uri;
 
 	/* Undo support */
 	GSList	   *undo_commands;
@@ -40,6 +46,8 @@ struct _Workbook {
 	gboolean during_destruction;
 	gboolean being_reordered;
 	gboolean recursive_dirty_enabled;
+	gboolean being_loaded;
+#endif
 };
 
 typedef struct {
@@ -50,9 +58,6 @@ typedef struct {
 	void (*sheet_deleted)       (Workbook *wb);
 } WorkbookClass;
 
-#define WORKBOOK_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), WORKBOOK_TYPE, WorkbookClass))
-#define IS_WORKBOOK_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), WORKBOOK_TYPE))
-
 #define WORKBOOK_FOREACH_VIEW(wb, view, code)					\
 do {										\
 	int InD;								\
